#  tests for pyproj-1.9.6-py36h6782396_0 (this is a generated file);
print('===== testing package: pyproj-1.9.6-py36h6782396_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import pyproj
pyproj.test()

from pyproj import Proj
Proj(init='epsg:4269')
#  --- run_test.py (end) ---

print('===== pyproj-1.9.6-py36h6782396_0 OK =====');
print("import: 'pyproj'")
import pyproj

